package nettytest;

import java.net.InetSocketAddress;
import java.util.concurrent.Executors;
import java.util.concurrent.TimeUnit;

import org.jboss.netty.bootstrap.ServerBootstrap;
import org.jboss.netty.channel.ChannelFactory;
import org.jboss.netty.channel.ChannelPipeline;
import org.jboss.netty.channel.socket.nio.NioClientSocketChannelFactory;
import org.jboss.netty.channel.socket.nio.NioServerSocketChannelFactory;
import org.jboss.netty.handler.timeout.HashedWheelTimer;
import org.jboss.netty.handler.timeout.ReadTimeoutHandler;
import org.jboss.netty.handler.timeout.Timer;
import org.jboss.netty.handler.timeout.WriteTimeoutHandler;

public class NettyTestServer {
    
    private static final int port = 12345;

    public static void main(String[] args) {
	ChannelFactory factory = new NioServerSocketChannelFactory(Executors.newCachedThreadPool(), Executors
		.newCachedThreadPool());
	ServerBootstrap bootstrap = new ServerBootstrap(factory);
	ChannelPipeline pipeline = bootstrap.getPipeline();

	Timer timer = new HashedWheelTimer(10, TimeUnit.MILLISECONDS, 10);
	pipeline.addLast("readTimeout", new ReadTimeoutHandler(timer, 10, TimeUnit.SECONDS));
	pipeline.addLast("writeTimeout", new WriteTimeoutHandler(timer, 5, TimeUnit.SECONDS));

	pipeline.addLast("handler", new TestHandler());

	bootstrap.setOption("child.tcpNoDelay", true);
	bootstrap.setOption("child.keepAlive", true);
	bootstrap.bind(new InetSocketAddress(port));

	System.out.println("server started...");
    }

}
