package nettytest;

import java.text.SimpleDateFormat;
import java.util.Date;

import org.jboss.netty.buffer.ChannelBuffer;
import org.jboss.netty.buffer.ChannelBuffers;
import org.jboss.netty.channel.Channel;
import org.jboss.netty.channel.ChannelHandlerContext;
import org.jboss.netty.channel.ChannelPipelineCoverage;
import org.jboss.netty.channel.ChannelStateEvent;
import org.jboss.netty.channel.ExceptionEvent;
import org.jboss.netty.channel.MessageEvent;
import org.jboss.netty.channel.SimpleChannelHandler;
import org.jboss.netty.handler.timeout.ChannelReadTimeoutException;
import org.jboss.netty.handler.timeout.ChannelWriteTimeoutException;

@ChannelPipelineCoverage("all")
public class TestHandler extends SimpleChannelHandler {
    
    @Override
    public void messageReceived(ChannelHandlerContext ctx, MessageEvent e) {
	ChannelBuffer buf = (ChannelBuffer) e.getMessage();
	long currentTimeMillis = buf.readLong();	
	System.out.println((new SimpleDateFormat("HH:mm:ss.SSS").format(new Date(currentTimeMillis))));
    }

    @Override
    public void exceptionCaught(ChannelHandlerContext ctx, ExceptionEvent e) {
	if (e.getCause() instanceof ChannelWriteTimeoutException) {
	    System.out.println(new SimpleDateFormat("HH:mm:ss.SSS").format(new Date())+" writetimeout");
	    writeTime(e.getChannel());
	} else if (e.getCause() instanceof ChannelReadTimeoutException) {
	    System.out.println(new SimpleDateFormat("HH:mm:ss.SSS").format(new Date())+" readtimeout");
	    writeTime(e.getChannel());
	} else {
	    e.getCause().printStackTrace();
	    Channel ch = e.getChannel();
	    ch.close().awaitUninterruptibly();
	    System.out.println("channel closed");
	}
    }

    @Override
    public void channelConnected(ChannelHandlerContext ctx, ChannelStateEvent e) {
	Channel ch = e.getChannel();
	System.out.println("channel connected: " + ch);
	writeTime(ch);
    }

    private void writeTime(Channel ch) {
	ChannelBuffer time = ChannelBuffers.buffer(10);
	time.writeLong(System.currentTimeMillis());
	ch.write(time);
    }
}
